@@ -86,7 +86,7 @@
 #define KPACKAGE_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KPACKAGE_NO_DEPRECATED
-#  define KPACKAGE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55800
+#  define KPACKAGE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55d00
 #endif
 #ifdef KPACKAGE_NO_DEPRECATED_WARNINGS
 #  define KPACKAGE_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KPACKAGE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KPACKAGE_DEPRECATED_WARNINGS_SINCE KPACKAGE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KPACKAGE_DEPRECATED_WARNINGS_SINCE 0x55800
+#    define KPACKAGE_DEPRECATED_WARNINGS_SINCE 0x55d00
 #  endif
 #endif
 
@@ -198,7 +198,7 @@
 #define KPACKAGE_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KPACKAGE_NO_DEPRECATED
-#  define KPACKAGE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55800
+#  define KPACKAGE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55d00
 #endif
 #ifdef KPACKAGE_NO_DEPRECATED_WARNINGS
 #  define KPACKAGE_DEPRECATED_WARNINGS_SINCE 0
@@ -208,7 +208,7 @@
 #  ifdef KPACKAGE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KPACKAGE_DEPRECATED_WARNINGS_SINCE KPACKAGE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KPACKAGE_DEPRECATED_WARNINGS_SINCE 0x55800
+#    define KPACKAGE_DEPRECATED_WARNINGS_SINCE 0x55d00
 #  endif
 #endif
 
